%def_without test

Name: krb5
Version: 1.6.3
Release: alt3

%define _docdir %_defaultdocdir/%name-%version

Summary: The Kerberos network authentication system
License: MIT
Group: System/Libraries
Url: http://web.mit.edu/kerberos/www/

Source0: %name-%version.tar.bz2
Source1: %name-doc.tar.bz2
Source2: %name-alt.tar

BuildRequires(pre): /dev/pts /proc
%{?_with_test:buildrequires: tcsh dejagnu telnet}
BuildRequires: flex libe2fs-devel libkeyutils-devel libldap-devel libncurses-devel libssl-devel libtinfo-devel tcl-devel

%description
Kerberos V5 is a trusted-third-party network authentication system,
which can improve your network's security by eliminating the insecure
practice of cleartext passwords.

# {{{ subpackages

%package -n lib%name
Summary: The shared libraries used by Kerberos 5
Group: System/Libraries
Requires: gawk

%package -n lib%name-ldap
Summary: The shared Kerberos 5 libraries, LDAP support
Group: System/Libraries

%package -n lib%name-devel
Summary: Development files needed to compile Kerberos 5 programs
Group: System/Libraries
Requires: lib%name = %version-%release
Requires: libe2fs-devel
Requires: libkeyutils-devel

%package kdc
Group: System/Servers
Summary: The Kerberos 5 Key Distribution Center
Requires: lib%name = %version-%release
Requires(post): %install_info
Requires(preun): %uninstall_info

%package kadmin
Group: System/Servers
Summary: The KDC admin programs for Kerberos 5
Requires: lib%name = %version-%release

%package kinit
Summary: Kerberos 5 programs for use on workstations
Group: System/Base
Requires: lib%name = %version-%release
Requires(post): %install_info
Requires(preun): %uninstall_info

%package services
Group: System/Servers
Summary: Set of commonly used kerberized services
Requires: lib%name = %version-%release

%package clients
Group: Networking/Other
Summary: Set of commonly used kerberized network programs
Requires: lib%name = %version-%release

%package doc
Group: Books/Computer books
Summary: Kerberos 5 documentation

# compat subpackages
%package server 
Group: System/Servers
Summary: The server programs for Kerberos 5
Requires: %name-kdc = %version-%release
Requires: %name-services = %version-%release

%package workstation
Group: System/Base
Summary: Kerberos 5 programs for use on workstations
Requires: %name-kinit = %version-%release
Requires: %name-clients = %version-%release


%description -n lib%name
Kerberos is a network authentication system.  This package contains
the shared libraries needed by Kerberos 5.  If you are using Kerberos,
you need to install this package.

%description -n lib%name-ldap
Kerberos is a network authentication system.  This package contains
the shared Kerberos 5 libraries needed for LDAP backend support.

%description -n lib%name-devel
Kerberos is a network authentication system.  This package contains the
header files and libraries needed for compiling Kerberos 5 programs.
If you want to develop Kerberos-aware programs, you need to install
this package.

%description kdc
Kerberos is a network authentication system.
This package contains the programs that must be installed
on a Kerberos 5 Key Distribution Center.

%description kadmin
Kerberos is a network authentication system.
This package contains set of programs helping to manage
a Kerberos 5 Key Distribution Center.

%description kinit
Kerberos is a network authentication system.
This package contains the basic Kerberos programs.
If your network uses Kerberos, this package should be installed
on every workstation.

%description services
Kerberos is a network authentication system.
This package contains kerberized versions of commonly used services,
such as Telnet or FTP.
You should have good reasons to install it.

%description clients
Kerberos is a network authentication system.
This package contains kerberized versions of common
network-related client programs such as Telnet or FTP.

%description doc
Kerberos is a network authentication system.
This packages contains documentation bundled with 
MIT Kerberos.

%description server
Kerberos is a network authentication system. This package contains
the programs that must be installed on a Kerberos 5 server.  If you
are installing a Kerberos 5 server, you need to install this package
(in other words, most people should NOT install this package).

%description workstation
Kerberos is a network authentication system.  This package contains the
basic Kerberos programs (kinit, klist, kdestroy, kpasswd) as well as
kerberized versions of Telnet and FTP.

# }}}

%prep
%setup

%build
util/reconf --verbose --force
DEFINES="-D_FILE_OFFSET_BITS=64" ; export DEFINES
%add_optflags -I/usr/include/et
%configure \
	--enable-shared --disable-static \
	--localstatedir=%_localstatedir/kerberos \
	--with-system-et \
	--with-system-ss \
	--without-krb4 \
	--with-ldap \
	--enable-dns \
	--enable-dns-for-kdc \
	--enable-dns-for-realm \
	--with-netlib=-lresolv \
	--includedir=%_includedir/%name \
	#
make all %{?_with_test:check}

%install
make install DESTDIR=%buildroot INSTALL_SETUID='%__install -m0755'

# Relocate *some* shared libraries
mkdir -p %buildroot/%_lib
for lib in libdes425 libgssapi_krb5 libk5crypto libkrb5 libkrb5support; do
  mv %buildroot%_libdir/${lib}.so.* %buildroot/%_lib
  ln -snf ../../%_lib/`readlink %buildroot%_libdir/${lib}.so` %buildroot%_libdir/${lib}.so
done

# Fix binaries clashes
for i in ftp rcp rlogin rsh telnet uuclient; do
  mv -f %buildroot%_bindir/$i %buildroot%_bindir/%name-$i
done

for i in ftpd telnetd uuserver; do
  mv -f %buildroot%_sbindir/$i %buildroot%_sbindir/%name-$i
done

mv -f %buildroot%_sbindir/login.krb5 %buildroot%_sbindir/%name-login
ln -s %name-login %buildroot%_sbindir/login.krb5

# Fix manpages clashes
for i in ftp rcp rlogin rsh telnet uuclient ; do
  if [ -f %buildroot%_man1dir/$i.1 ] ; then
    mv %buildroot%_man1dir/$i.1 %buildroot%_man1dir/%name-$i.1
  fi
done

for i in ftpd telnetd ; do
  if [ -f %buildroot%_man8dir/$i.8 ] ; then
    mv %buildroot%_man8dir/$i.8 %buildroot%_man8dir/%name-$i.8
  fi
done

ln -s login.krb5.8 %buildroot%_man8dir/%name-login.8

# Server init scripts, xinetd configuration files,
# sample client config file and sample KDC config files.
tar xf %SOURCE2 -C %buildroot

# Install docs
rm -rf %buildroot%_docdir
mkdir -p %buildroot%_infodir %buildroot%_docdir
tar xf %SOURCE1 -C %buildroot%_docdir
cp -p plugins/kdb/ldap/libkdb_ldap/kerberos.{ldif,schema} %buildroot%_docdir
mv %buildroot%_docdir/krb5-{admin,install,user}.info %buildroot%_infodir
gzip %buildroot%_docdir/*.ps

# cleanups
rm -rf %buildroot%_datadir/gnats %buildroot%_datadir/examples
rm -rf %buildroot%_includedir/krb5/kerberosIV
rm -f %buildroot%_man1dir/tmac.doc*

%post -n lib%name -p %post_ldconfig
%postun -n lib%name -p %postun_ldconfig

%post kdc
%post_service krb5kdc
%post_service kadmin
%post_service kprop
%install_info %name-{admin,install}.info

%post kinit
%install_info %name-user.info

%preun kdc
%preun_service krb5kdc
%preun_service kadmin
%preun_service kprop
%uninstall_info %name-{admin,install}.info

%preun kinit
%uninstall_info %name-user.info

%files -n lib%name
%config %_initdir/kdcrotate
%config(noreplace) %_sysconfdir/krb5.conf

/%_lib/lib*.so.*

%_libdir/libgssrpc.so.*
%_libdir/libkadm5clnt.so.*
%_libdir/libkadm5srv.so.*
%_libdir/libkdb5.so.*

%dir %_libdir/%name
%dir %_libdir/%name/plugins
%dir %_libdir/%name/plugins/kdb
%dir %_libdir/%name/plugins/preauth
%_libdir/%name/plugins/kdb/db2.so
%_libdir/%name/plugins/preauth/pkinit.so

%_man5dir/krb5.conf.5*

%files -n lib%name-ldap
%_libdir/libkdb_ldap.so.*
%_libdir/%name/plugins/kdb/kldap.so

%files -n lib%name-devel
%dir %_includedir/krb5
%_includedir/krb5/*
%_libdir/lib*.so
%_bindir/gss-client
%_bindir/sclient
%_bindir/krb5-config
%_bindir/sim_client
%_sbindir/gss-server
%_sbindir/krb5-send-pr
%_sbindir/sim_server
%_sbindir/sserver
%_man1dir/sclient.1*
%_man1dir/krb5-config.1*
%_man1dir/krb5-send-pr.1*
%_man8dir/sserver.8*

%files kdc
%dir %_localstatedir/kerberos
%dir %_localstatedir/kerberos/krb5kdc
%config(noreplace) %_localstatedir/kerberos/krb5kdc/kdc.conf
%config(noreplace) %_localstatedir/kerberos/krb5kdc/kadm5.acl
%config %_initdir/kadmin
%config %_initdir/krb5kdc
%config %_initdir/kprop

%_sbindir/kadmin.local
%_sbindir/kadmind
%_sbindir/k5srvutil
%_sbindir/kdb5_util
%_sbindir/kdb5_ldap_util
%_sbindir/kprop
%_sbindir/kpropd
%_sbindir/krb5kdc

%_infodir/%name-admin.info*
%_infodir/%name-install.info*

%_man5dir/kdc.conf.5*
%_man8dir/kadmin.local.8*
%_man8dir/kadmind.8*
%_man8dir/kdb5_util.8*
%_man8dir/kdb5_ldap_util.8*
%_man8dir/kprop.8*
%_man8dir/kpropd.8*
%_man8dir/krb5kdc.8*
%_man8dir/k5srvutil.8*

%files kadmin
%_sbindir/kadmin
%_sbindir/ktutil
%_man8dir/kadmin.8*
%_man8dir/ktutil.8*

%files kinit
%_bindir/kdestroy
%_bindir/kinit
%_bindir/klist
%_bindir/kpasswd
%_bindir/ksu
%_bindir/kvno

%_infodir/%name-user.info*

%_man1dir/kdestroy.1*
%_man1dir/kerberos.1*
%_man1dir/kinit.1*
%_man1dir/klist.1*
%_man1dir/kpasswd.1*
%_man1dir/ksu.1*
%_man1dir/kvno.1*
%_man5dir/.k5login.5*

%files services
%config(noreplace) %_sysconfdir/xinetd.d/*
%_sbindir/%name-login
%_sbindir/login.krb5

%_sbindir/klogind
%_sbindir/kshd

%_sbindir/%name-ftpd
%_sbindir/%name-telnetd
%_sbindir/%name-uuserver

%_man8dir/%name-login.8*
%_man8dir/login.%name.8*

%_man8dir/klogind.8*
%_man8dir/kshd.8*

%_man8dir/%name-ftpd.8*
%_man8dir/%name-telnetd.8*

%files clients
%_bindir/%name-ftp
%_bindir/%name-rcp
%_bindir/%name-rlogin
%_bindir/%name-rsh
%_bindir/%name-telnet
%_bindir/%name-uuclient

%_man1dir/%name-ftp.1*
%_man1dir/%name-rsh.1*
%_man1dir/%name-rlogin.1*
%_man1dir/%name-rcp.1*
%_man1dir/%name-telnet.1*

%files doc
%_docdir

%files server
%files workstation

# {{{ changelog

%changelog
* Mon Mar 17 2008 Sergey Bolshakov <sbolshakov@altlinux.ru> 1.6.3-alt3
- fixed:
  + MITKRB5-SA-2008-001
  + MITKRB5-SA-2008-002

* Fri Jan 11 2008 Sergey Bolshakov <sbolshakov@altlinux.ru> 1.6.3-alt2
- added req on libkeyutils-devel to krb5-devel subpackage (#13977)

* Sat Jan  5 2008 Sergey Bolshakov <sbolshakov@altlinux.ru> 1.6.3-alt1
- 1.6.3 released

* Fri Sep  7 2007 Sergey Bolshakov <sbolshakov@altlinux.ru> 1.5.1-alt7
- MITKRB5-SA-2007-006 fix revised

* Tue Sep  4 2007 Sergey Bolshakov <sbolshakov@altlinux.ru> 1.5.1-alt6
- fixed:
  + MITKRB5-SA-2007-006

* Tue Jun 26 2007 Sergey Bolshakov <sbolshakov@altlinux.ru> 1.5.1-alt5
- fixed:
  + MITKRB5-SA-2007-004
  + MITKRB5-SA-2007-005

* Wed Apr  4 2007 Sergey Bolshakov <sbolshakov@altlinux.ru> 1.5.1-alt4
- fixed:
  + MITKRB5-SA-2007-001
  + MITKRB5-SA-2007-002
  + MITKRB5-SA-2007-003

* Sat Jan 13 2007 Sergey Bolshakov <sbolshakov@altlinux.ru> 1.5.1-alt3
- kadmind: MITKRB5-SA-2006-002, MITKRB5-SA-2006-003
- bug fixed: #10494

* Sat Oct 28 2006 Sergey Bolshakov <sbolshakov@altlinux.ru> 1.5.1-alt2
- packaged missing db2 plugin

* Sat Oct  7 2006 Sergey Bolshakov <sbolshakov@altlinux.ru> 1.5.1-alt1
- 1.5.1 released
- patches rediffed & applied:
  + krb5-1.3-alt-rh-manpage-paths.patch
  + krb5-1.3-rh-netkit-rsh.patch
  + krb5-1.4-alt-rh-rlogind-environ.patch
  + krb5-1.3-rh-ksu-access.patch
  + krb5-1.3-rh-ksu-path.patch
  + krb5-1.1.1-rh-brokenrev.patch
  + krb5-1.2.1-rh-passive.patch
  + krb5-1.4-rh-ktany.patch
  + krb5-1.3-rh-large-file.patch
  + krb5-1.3-rh-ftp-glob.patch
  + krb5-1.3-rh-check.patch
  + krb5-1.2.7-rh-reject-bad-transited.patch
  + krb5-1.3.1-rh-dns.patch
  + krb5-1.4-rh-null.patch
  + krb5-1.3.3-rh-rcp-sendlarge.patch
  + krb5-1.3.5-rh-kprop-mktemp.patch
  + krb5-1.3.6-alt-send-pr.patch
  + krb5-1.4.1-rh-api.patch
  + krb5-1.4.1-rh-telnet-environ.patch
  + krb5-1.4.3-rh-enospc.patch
  + krb5-1.5-rh-fclose.patch
  + krb5-1.5-rh-gssinit.patch
  + krb5-1.5-rh-io.patch
  + krb5-1.5.1-alt-tinfo.patch
  + krb5-1.5.1-alt-norpath.patch
  + krb5-1.5.1-alt-krb5config.patch
  + krb5-1.5.1-alt-krb5-rlogin-prog.patch
  + krb5-1.5.1-alt-kadmind-pidfile.patch

* Sat Apr 15 2006 Sergey Bolshakov <sbolshakov@altlinux.ru> 1.4.3-alt2
- fixed #9408

* Sat Apr  8 2006 Sergey Bolshakov <sbolshakov@altlinux.ru> 1.4.3-alt1
- 1.4.3
- linked against system libss

* Sun Jun 19 2005 Sergey Bolshakov <sbolshakov@altlinux.ru> 1.4.1-alt1
- 1.4.1
- subpackages rearranged:
  + made new -kdc, -kadmin and -kinit subpackages
  + old -server and -workstation now contains no data
  + extra docs packaged separately to -doc subpackage
- some libraries returned back to %%_libdir
- bugs fixed: #6109, #6678, #6727

* Fri Jan 21 2005 Sergey Bolshakov <sbolshakov@altlinux.ru> 1.3.6-alt1
- 1.3.6

* Mon Aug 30 2004 Dmitry V. Levin <ldv@altlinux.org> 1.3.1-alt5
- NMU, fixes:
  + MITKRB5-SA-2004-001,
  + MITKRB5-SA-2004-002,
  + MITKRB5-SA-2004-003.

* Mon Jun 28 2004 ALT QA Team Robot <qa-robot@altlinux.org> 1.3.1-alt4.1
- Removed unneeded %%set_*_version calls.

* Tue Feb 24 2004 Alexander Bokovoy <ab@altlinux.ru> 1.3.1-alt4
- Force -I%_includedir/et in krb5-config

* Fri Feb 13 2004 Alexander Bokovoy <ab@altlinux.ru> 1.3.1-alt3
- Fixed:
    + #3494, #3655, #3136, and #2770
- Changed:
    + Libraries moved from %_libdir/krb5 to /lib
- Added:
    + Compile krb5 against system libcom_err from libe2fs
- Removed:
    + Static libraries

* Mon Sep 29 2003 Alexander Bokovoy <ab@altlinux.ru> 1.3.1-alt2
- Added:
    + all init scripts moved to start-stop-daemon approach
- Fixed:
    + #2875, in kpropd and kadmind initscripts
- Removed:
    + Kerberos IV support

* Mon Sep 29 2003 Alexander Bokovoy <ab@altlinux.ru> 1.3.1-alt1
- 1.3.1 release (with support for RC4-HMAC encryption type)

* Mon Mar 24 2003 Alexander Bokovoy <ab@altlinux.ru> 1.2.7-alt2
- Fixed:
    + MITKRB5-SA-2003-03
    + CAN-2003-0072
    + CAN-2003-0082

* Sat Feb 15 2003 Alexander Bokovoy <ab@altlinux.ru> 1.2.7-alt1
- 1.2.7
- Fixed:
    + krb5-config to reflect our layout
    + localstatedir to %_localstatedir/kerberos
    + description of lib%name-devel
- Splitted:
    + statically compiled libraries to lib%name-devel-static

* Mon Jan 27 2003 Alexander Bokovoy <ab@altlinux.ru> 1.2.5.1-alt2
- Merge AW changes with Sisyphus

* Mon Jan 20 2003 Grigory Milev <week@altlinux.ru> 1.2.5.1-5aw
- spec cleanup

* Thu Jan  9 2003 Grigory Milev <week@altlinux.ru> 1.2.5.1-4aw
- AW adaptations

* Mon Dec 30 2002 Alexander Bokovoy <ab@altlinux.ru> 1.2.5.1-alt1
- Integrate krb5-current into Sisyphus
- Patch list revised
- Move various samples to libkrb5-devel

* Wed Sep 04 2002 Alexander Bokovoy <ab@optifacio.com> 1.2.5.1-1aw
- Integrate krb5-current to get access to enc.type 23
- remove libtinfo/samba support as it is not required yet.

* Mon Aug 05 2002 Alexander Bokovoy <ab@altlinux.ru> 1.2.5-alt1
- New release
- Fixed:
    + MITKRB5-SA-2002-001: Remote root vulnerability in MIT krb5 admin system
- Added but not compiled in yet:
    + A patch from Andrew Tridgell to better support Samba 3.0 ADS mode

* Thu Jul 18 2002 Alexander Bokovoy <ab@altlinux.ru> 1.2.2-alt7
- Build against libtinfo, get rid of termcap/ncurses

* Sat Mar 02 2002 Alexander Bokovoy <ab@altlinux.ru> 1.2.2-alt6
- Fixed:
    + %_includedir/krb5 ownership

* Thu Jan 03 2002 Alexander Bokovoy <ab@altlinux.ru> 1.2.2-alt5
- Fixed:
    + documentation clashes with overriden utilites

* Tue Dec 18 2001 Alexander Bokovoy <ab@altlinux.ru> 1.2.2-alt4
- Fixed:
    + paths in xinet.d services
    + /var/kerberos moved to %_localstatedir/kerberos (FHS)

* Mon Dec 17 2001 Alexander Bokovoy <ab@altlinux.ru> 1.2.2-alt3
- Fixed:
    + postin/un scripts for lib%name

* Sat Dec 15 2001 Alexander Bokovoy <ab@altlinux.ru> 1.2.2-alt2
- Fixed:
    + Info pages for server/workstation

* Tue Dec 11 2001 Alexander Bokovoy <ab@altlinux.ru> 1.2.2-alt1
- Initial build for ALT Linux based on Applianceware version
- Fixed:
    + all libs moved to %_libdir/krb5/, includes to %_includedir/krb5
    + postinstall/postuninstall scripts for libs
    + dependencies for several sub-packages to eliminate file deps.
    + krb5-send-pr to not expose direct Requires: to nis/yp utils
- Packages renamed:
    + %name-libs -> lib%name
    + %name-devel -> lib%name-devel

* Fri Aug  3 2001 Nalin Dahyabhai <nalin@redhat.com>
- bump release number and rebuild

* Wed Aug  1 2001 Nalin Dahyabhai <nalin@redhat.com>
- add patch to fix telnetd vulnerability

* Fri Jul 20 2001 Nalin Dahyabhai <nalin@redhat.com>
- tweak statglue.c to fix stat/stat64 aliasing problems
- be cleaner in use of gcc to build shlibs

* Wed Jul 11 2001 Nalin Dahyabhai <nalin@redhat.com>
- use gcc to build shared libraries

* Wed Jun 27 2001 Nalin Dahyabhai <nalin@redhat.com>
- add patch to support "ANY" keytab type (i.e.,
  "default_keytab_name = ANY:FILE:/etc/krb5.keytab,SRVTAB:/etc/srvtab"
  patch from Gerald Britton, #42551)
- build with -D_FILE_OFFSET_BITS=64 to get large file I/O in ftpd (#30697)
- patch ftpd to use long long and %%lld format specifiers to support the SIZE
  command on large files (also #30697)
- don't use LOG_AUTH as an option value when calling openlog() in ksu (#45965)
- implement reload in krb5kdc and kadmind init scripts (#41911)
- lose the krb5server init script (not using it any more)

* Sun Jun 24 2001 Elliot Lee <sopwith@redhat.com>
- Bump release + rebuild.

* Tue May 29 2001 Nalin Dahyabhai <nalin@redhat.com>
- pass some structures by address instead of on the stack in krb5kdc

* Tue May 22 2001 Nalin Dahyabhai <nalin@redhat.com>
- rebuild in new environment

* Thu Apr 26 2001 Nalin Dahyabhai <nalin@redhat.com>
- add patch from Tom Yu to fix ftpd overflows (#37731)

* Wed Apr 18 2001 Than Ngo <than@redhat.com>
- disable optimizations on the alpha again

* Fri Mar 30 2001 Nalin Dahyabhai <nalin@redhat.com>
- add in glue code to make sure that libkrb5 continues to provide a
  weak copy of stat()

* Thu Mar 15 2001 Nalin Dahyabhai <nalin@redhat.com>
- build alpha with -O0 for now

* Thu Mar  8 2001 Nalin Dahyabhai <nalin@redhat.com>
- fix the kpropd init script

* Mon Mar  5 2001 Nalin Dahyabhai <nalin@redhat.com>
- update to 1.2.2, which fixes some bugs relating to empty ETYPE-INFO
- re-enable optimization on Alpha

* Thu Feb  8 2001 Nalin Dahyabhai <nalin@redhat.com>
- build alpha with -O0 for now
- own %_var/kerberos

* Tue Feb  6 2001 Nalin Dahyabhai <nalin@redhat.com>
- own the directories which are created for each package (#26342)

* Tue Jan 23 2001 Nalin Dahyabhai <nalin@redhat.com>
- gettextize init scripts

* Fri Jan 19 2001 Nalin Dahyabhai <nalin@redhat.com>
- add some comments to the ksu patches for the curious
- re-enable optimization on alphas

* Mon Jan 15 2001 Nalin Dahyabhai <nalin@redhat.com>
- fix krb5-send-pr (#18932) and move it from -server to -workstation
- buildprereq libtermcap-devel
- temporariliy disable optimization on alphas
- gettextize init scripts

* Tue Dec  5 2000 Nalin Dahyabhai <nalin@redhat.com>
- force -fPIC

* Fri Dec  1 2000 Nalin Dahyabhai <nalin@redhat.com>
- rebuild in new environment

* Tue Oct 31 2000 Nalin Dahyabhai <nalin@redhat.com>
- add bison as a BuildPrereq (#20091)

* Mon Oct 30 2000 Nalin Dahyabhai <nalin@redhat.com>
- change /usr/dict/words to /usr/share/dict/words in default kdc.conf (#20000)

* Thu Oct  5 2000 Nalin Dahyabhai <nalin@redhat.com>
- apply kpasswd bug fixes from David Wragg

* Wed Oct  4 2000 Nalin Dahyabhai <nalin@redhat.com>
- make krb5-libs obsolete the old krb5-configs package (#18351)
- don't quit from the kpropd init script if there's no principal database so
  that you can propagate the first time without running kpropd manually
- don't complain if /etc/ld.so.conf doesn't exist in the -libs %post

* Tue Sep 12 2000 Nalin Dahyabhai <nalin@redhat.com>
- fix credential forwarding problem in klogind (goof in KRB5CCNAME handling)
  (#11588)
- fix heap corruption bug in FTP client (#14301)

* Wed Aug 16 2000 Nalin Dahyabhai <nalin@redhat.com>
- fix summaries and descriptions
- switched the default transfer protocol from PORT to PASV as proposed on
  bugzilla (#16134), and to match the regular ftp package's behavior

* Wed Jul 19 2000 Jeff Johnson <jbj@redhat.com>
- rebuild to compress man pages.

* Sat Jul 15 2000 Bill Nottingham <notting@redhat.com>
- move initscript back

* Fri Jul 14 2000 Nalin Dahyabhai <nalin@redhat.com>
- disable servers by default to keep linuxconf from thinking they need to be
  started when they don't

* Thu Jul 13 2000 Prospector <bugzilla@redhat.com>
- automatic rebuild

* Mon Jul 10 2000 Nalin Dahyabhai <nalin@redhat.com>
- change cleanup code in post to not tickle chkconfig
- add grep as a Prereq: for -libs

* Thu Jul  6 2000 Nalin Dahyabhai <nalin@redhat.com>
- move condrestarts to postun
- make xinetd configs noreplace
- add descriptions to xinetd configs
- add /etc/init.d as a prereq for the -server package
- patch to properly truncate $TERM in krlogind

* Fri Jun 30 2000 Nalin Dahyabhai <nalin@redhat.com>
- update to 1.2.1
- back out Tom Yu's patch, which is a big chunk of the 1.2 -> 1.2.1 update
- start using the official source tarball instead of its contents

* Thu Jun 29 2000 Nalin Dahyabhai <nalin@redhat.com>
- Tom Yu's patch to fix compatibility between 1.2 kadmin and 1.1.1 kadmind
- pull out 6.2 options in the spec file (sonames changing in 1.2 means it's not
  compatible with other stuff in 6.2, so no need)

* Wed Jun 28 2000 Nalin Dahyabhai <nalin@redhat.com>
- tweak graceful start/stop logic in post and preun

* Mon Jun 26 2000 Nalin Dahyabhai <nalin@redhat.com>
- update to the 1.2 release
- ditch a lot of our patches which went upstream
- enable use of DNS to look up things at build-time
- disable use of DNS to look up things at run-time in default krb5.conf
- change ownership of the convert-config-files script to root.root
- compress PS docs
- fix some typos in the kinit man page
- run condrestart in server post, and shut down in preun

* Mon Jun 19 2000 Nalin Dahyabhai <nalin@redhat.com>
- only remove old krb5server init script links if the init script is there

* Sat Jun 17 2000 Nalin Dahyabhai <nalin@redhat.com>
- disable kshell and eklogin by default

* Thu Jun 15 2000 Nalin Dahyabhai <nalin@redhat.com>
- patch mkdir/rmdir problem in ftpcmd.y
- add condrestart option to init script
- split the server init script into three pieces and add one for kpropd

* Wed Jun 14 2000 Nalin Dahyabhai <nalin@redhat.com>
- make sure workstation servers are all disabled by default
- clean up krb5server init script

* Fri Jun  9 2000 Nalin Dahyabhai <nalin@redhat.com>
- apply second set of buffer overflow fixes from Tom Yu
- fix from Dirk Husung for a bug in buffer cleanups in the test suite
- work around possibly broken rev binary in running test suite
- move default realm configs from /var/kerberos to %_var/kerberos

* Tue Jun  6 2000 Nalin Dahyabhai <nalin@redhat.com>
- make ksu and v4rcp owned by root

* Sat Jun  3 2000 Nalin Dahyabhai <nalin@redhat.com>
- use %%{_infodir} to better comply with FHS
- move .so files to -devel subpackage
- tweak xinetd config files (bugs #11833, #11835, #11836, #11840)
- fix package descriptions again

* Wed May 24 2000 Nalin Dahyabhai <nalin@redhat.com>
- change a LINE_MAX to 1024, fix from Ken Raeburn
- add fix for login vulnerability in case anyone rebuilds without krb4 compat
- add tweaks for byte-swapping macros in krb.h, also from Ken
- add xinetd config files
- make rsh and rlogin quieter
- build with debug to fix credential forwarding
- add rsh as a build-time req because the configure scripts look for it to
  determine paths

* Wed May 17 2000 Nalin Dahyabhai <nalin@redhat.com>
- fix config_subpackage logic

* Tue May 16 2000 Nalin Dahyabhai <nalin@redhat.com>
- remove setuid bit on v4rcp and ksu in case the checks previously added
  don't close all of the problems in ksu
- apply patches from Jeffrey Schiller to fix overruns Chris Evans found
- reintroduce configs subpackage for use in the errata
- add PreReq: sh-utils

* Mon May 15 2000 Nalin Dahyabhai <nalin@redhat.com>
- fix double-free in the kdc (patch merged into MIT tree)
- include convert-config-files script as a documentation file

* Wed May 03 2000 Nalin Dahyabhai <nalin@redhat.com>
- patch ksu man page because the -C option never works
- add access() checks and disable debug mode in ksu
- modify default ksu build arguments to specify more directories in CMD_PATH
  and to use getusershell()

* Wed May 03 2000 Bill Nottingham <notting@redhat.com>
- fix configure stuff for ia64

* Mon Apr 10 2000 Nalin Dahyabhai <nalin@redhat.com>
- add LDCOMBINE=-lc to configure invocation to use libc versioning (bug #10653)
- change Requires: for/in subpackages to include %version

* Wed Apr 05 2000 Nalin Dahyabhai <nalin@redhat.com>
- add man pages for kerberos(1), kvno(1), .k5login(5)
- add kvno to -workstation

* Mon Apr 03 2000 Nalin Dahyabhai <nalin@redhat.com>
- Merge krb5-configs back into krb5-libs.  The krb5.conf file is marked as
  a %%config file anyway.
- Make krb5.conf a noreplace config file.

* Thu Mar 30 2000 Nalin Dahyabhai <nalin@redhat.com>
- Make klogind pass a clean environment to children, like NetKit's rlogind does.

* Wed Mar 08 2000 Nalin Dahyabhai <nalin@redhat.com>
- Don't enable the server by default.
- Compress info pages.
- Add defaults for the PAM module to krb5.conf

* Mon Mar 06 2000 Nalin Dahyabhai <nalin@redhat.com>
- Correct copyright: it's exportable now, provided the proper paperwork is
  filed with the government.

* Fri Mar 03 2000 Nalin Dahyabhai <nalin@redhat.com>
- apply Mike Friedman's patch to fix format string problems
- don't strip off argv[0] when invoking regular rsh/rlogin

* Thu Mar 02 2000 Nalin Dahyabhai <nalin@redhat.com>
- run kadmin.local correctly at startup

* Mon Feb 28 2000 Nalin Dahyabhai <nalin@redhat.com>
- pass absolute path to kadm5.keytab if/when extracting keys at startup

* Sat Feb 19 2000 Nalin Dahyabhai <nalin@redhat.com>
- fix info page insertions

* Wed Feb  9 2000 Nalin Dahyabhai <nalin@redhat.com>
- tweak server init script to automatically extract kadm5 keys if
  /var/kerberos/krb5kdc/kadm5.keytab doesn't exist yet
- adjust package descriptions

* Thu Feb  3 2000 Nalin Dahyabhai <nalin@redhat.com>
- fix for potentially gzipped man pages

* Fri Jan 21 2000 Nalin Dahyabhai <nalin@redhat.com>
- fix comments in krb5-configs

* Fri Jan  7 2000 Nalin Dahyabhai <nalin@redhat.com>
- move /usr/kerberos/bin to end of PATH

* Tue Dec 28 1999 Nalin Dahyabhai <nalin@redhat.com>
- install kadmin header files

* Tue Dec 21 1999 Nalin Dahyabhai <nalin@redhat.com>
- patch around TIOCGTLC defined on alpha and remove warnings from libpty.h
- add installation of info docs
- remove krb4 compat patch because it doesn't fix workstation-side servers

* Mon Dec 20 1999 Nalin Dahyabhai <nalin@redhat.com>
- remove hesiod dependency at build-time

* Sun Dec 19 1999 Nalin Dahyabhai <nsdahya1@eos.ncsu.edu>
- rebuild on 1.1.1

* Thu Oct  7 1999 Nalin Dahyabhai <nsdahya1@eos.ncsu.edu>
- clean up init script for server, verify that it works [jlkatz]
- clean up rotation script so that rc likes it better
- add clean stanza

* Mon Oct  4 1999 Nalin Dahyabhai <nsdahya1@eos.ncsu.edu>
- backed out ncurses and makeshlib patches
- update for krb5-1.1
- add KDC rotation to rc.boot, based on ideas from Michael's C version

* Mon Sep 26 1999 Nalin Dahyabhai <nsdahya1@eos.ncsu.edu>
- added -lncurses to telnet and telnetd makefiles

* Mon Jul  5 1999 Nalin Dahyabhai <nsdahya1@eos.ncsu.edu>
- added krb5.csh and krb5.sh to /etc/profile.d

* Mon Jun 22 1999 Nalin Dahyabhai <nsdahya1@eos.ncsu.edu>
- broke out configuration files

* Mon Jun 14 1999 Nalin Dahyabhai <nsdahya1@eos.ncsu.edu>
- fixed server package so that it works now

* Sat May 15 1999 Nalin Dahyabhai <nsdahya1@eos.ncsu.edu>
- started changelog
- updated existing 1.0.5 RPM from Eos Linux to krb5 1.0.6
- added --force to makeinfo commands to skip errors during build

# }}}

